==> nifi-minifi-cpp-0.15.0-source.tar.gz: nifi-minifi-cpp-0.15.0-source/nanofi/src/cxx/CallbackProcessor.cpp <==
/**
 *
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
#include "cxx/CallbackProcessor.h"
#include "core/cxxstructs.h"
#include "core/Resource.h"

namespace org::apache::nifi::minifi::processors {

void CallbackProcessor::initialize() {
  setSupportedRelationships(Relationships);
}

void CallbackProcessor::onSchedule(core::ProcessContext *context, core::ProcessSessionFactory* /*sessionFactory*/) {
  if (onschedule_callback_ != nullptr) {
    onschedule_callback_(context);
  }
}

void CallbackProcessor::onTrigger(core::ProcessContext *context, core::ProcessSession *session) {
 if (ontrigger_callback_ != nullptr) {
   ontrigger_callback_(session, context);
 }
}

REGISTER_RESOURCE(CallbackProcessor, Processor);

}  // namespace org::apache::nifi::minifi::processors

==> nifi-minifi-cpp-0.99.0-source.tar.gz: nifi-minifi-cpp-0.99.0-source/nanofi/src/cxx/CallbackProcessor.cpp <==
/**
 *
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
#include "cxx/CallbackProcessor.h"
#include "core/cxxstructs.h"
#include "core/Resource.h"

namespace org::apache::nifi::minifi::processors {

void CallbackProcessor::initialize() {
  setSupportedRelationships(Relationships);
}

void CallbackProcessor::onSchedule(core::ProcessContext& context, core::ProcessSessionFactory&) {
  if (onschedule_callback_ != nullptr) {
    onschedule_callback_(&context);
  }
}

void CallbackProcessor::onTrigger(core::ProcessContext& context, core::ProcessSession& session) {
 if (ontrigger_callback_ != nullptr) {
   ontrigger_callback_(&session, &context);
 }
}

REGISTER_RESOURCE(CallbackProcessor, Processor);

}  // namespace org::apache::nifi::minifi::processors
